/**! media-query-parser | Tom Golden <oss@tom.bio> (https://tom.bio) | @license MIT  */
import { ConditionNode, FeatureNode, ParserError, QueryListNode, QueryNode, ValueNode } from "./utils.js";
/**
 * creates an AST from a **media-query-list** string; parses comma-separated media queries correctly
 *
 * Important:
 *
 * - _an invalid media-query child **does not** make the media-query-list invalid_
 * - can **return** a ParserError (e.g. when there is a CSS syntax error, like an invalid string)
 *
 * @example
 * ```ts
 * console.log(parseMediaQueryList(`print, invalid, (min-width: 1000px)`));
 * // {
 * //   type: "query-list",
 * //   mediaQueries: [
 * //     {type: "query", mediaType: "print"},
 * //     {type: "query", prefix: "not"},
 * //     {type: "query", mediaCondition: ...}
 * //   ],
 * // }
 * ```
 */
export declare const parseMediaQueryList: (str: string) => QueryListNode | ParserError;
/**
 * creates an AST from a **media-query** string
 * @example
 * ```ts
 * console.log(parseMediaQuery(`(monochrome)`));
 * // {
 * //   type: "query",
 * //   mediaCondition: {
 * //     type: "condition",
 * //     children: [{ type: "feature", context: "boolean", feature: "monochrome" }],
 * //   },
 * // }
 * ```
 */
export declare const parseMediaQuery: (str: string) => QueryNode | ParserError;
/**
 * creates an AST from a **media-condition** string
 *
 * @example
 * ```ts
 * console.log(parseMediaCondition(`((aspect-ratio > 1/2) or (monochrome))`));
 * // {
 * //   type: "condition",
 * //   children: [{
 * //     type: "condition",
 * //     children: [
 * //       {
 * //         type: "feature",
 * //         context: "range",
 * //         feature: "aspect-ratio",
 * //         range: {
 * //           featureName: "aspect-ratio",
 * //           rightOp: ">",
 * //           rightToken: { denominator: 2, numerator: 1, type: "ratio" },
 * //         },
 * //       },
 * //       { context: "boolean", feature: "monochrome", type: "feature" },
 * //     ],
 * //     operator: "or",
 * //   }],
 * // }
 *
 * ```
 */
export declare const parseMediaCondition: (str: string) => ConditionNode | ParserError;
/**
 * creates an AST from a **media-feature** string - including parentheses
 *
 * @example
 * ```ts
 * console.log(parseMediaFeature(`(min-width: 768px)`));
 * // {
 * //   type: "feature",
 * //   context: "value",
 * //   feature: "width",
 * //   prefix: "min",
 * //   value: { type: "dimension", flag: "number", unit: "px", value: 768 },
 * // }
 *
 * ```
 */
export declare const parseMediaFeature: (str: string) => FeatureNode | ParserError;
/**
 * turns an AST into an equivalent string
 *
 * @example
 * ```ts
 * console.log(stringify({
 *   type: "query",
 *   mediaCondition: {
 *     type: "condition",
 *     children: [{ type: "feature", context: "boolean", feature: "monochrome" }],
 *   },
 * }));
 * // "(monochrome)"
 * ```
 *
 * note: stringifying a MediaCondition directly will always wrap the condition with parentheses.
 * sometimes they are redundant, but calling this with a MediaQuery will remove them for you.
 * e.g. `stringify({ type: 'query', mediaType: 'all', mediaCondition: <your condition> })`
 *
 * @example
 * ```ts
 * console.log(stringify(parseMediaFeature(`(min-width: 768px)`)));
 * // "(min-width: 768px)"
 * ```
 */
export declare const stringify: (node: QueryListNode | QueryNode | ConditionNode | FeatureNode | ValueNode) => string;
export * from "./utils.js";
